require 'spec_helper'

describe Tracker::Deliverer do

  let(:tracker_token) { double }
  let(:project_id) { double }
  let(:committed_story) { double(id: 1) }
  let(:uncommitted_story) { double(id: 2) }
  let(:finished_stories) { [committed_story, uncommitted_story] }
  let(:project) { double }
  let(:git) { double }
  let(:deliverer) { Tracker::Deliverer.new(project, git) }

  describe '#mark_as_delivered' do
    context 'when called without argument' do
      it('should mark stories as delivered') do
        expect(project).to receive(:finished) { finished_stories }
        expect(git).to receive(:contains?).with(1, {}) { true }
        expect(git).to receive(:contains?).with(2, {}) { false }
        expect(project).to receive(:deliver).with(committed_story)
        expect(project).to_not receive(:deliver).with(uncommitted_story)
        expect(project).to_not receive(:comment).with(uncommitted_story)

        deliverer.mark_as_delivered
      end
    end

    context 'when given a specific branch' do
      it('should mark stories as delivered') do
        expect(project).to receive(:finished) { finished_stories }
        expect(git).to receive(:contains?).with(1, {branch: 'develop'}) { true }
        expect(git).to receive(:contains?).with(2, {branch: 'develop'}) { false }
        expect(project).to receive(:deliver).with(committed_story)
        expect(project).to_not receive(:deliver).with(uncommitted_story)
        expect(project).to_not receive(:comment)
        deliverer.mark_as_delivered('develop')
      end
    end

    context 'when given a specific server name' do
      it('should comment story with server name where story is delivered') do
        expect(project).to receive(:comment)
        expect(project).to receive(:finished) { finished_stories }
        expect(git).to receive(:contains?).with(1, {}) { true }
        expect(git).to receive(:contains?).with(2, {}) { false }
        expect(project).to receive(:deliver).with(committed_story)
        expect(project).not_to receive(:deldeliveriver).with(committed_story)

        deliverer.mark_as_delivered(nil, 'staging-server')
      end

    end
  end

end
